@@ -5,7 +5,7 @@
 (declaim (optimize (speed 2) (safety 3) #-allegro (debug 3)))
 (proclaim '(optimize (speed 2) (safety 3) #-allegro (debug 3)))
 
-(format t "Evaluating asdf/test/script-support~%")
+;;(format t "Evaluating asdf/test/script-support~%")
 
 ;; We can't use asdf:merge-pathnames* because ASDF isn't loaded yet.
 ;; We still want to work despite and host/device funkiness.
@@ -61,13 +61,7 @@
     #-(or clozure cmu sbcl scl) (namestring p)))
 
 ;;; code adapted from cl-launch http://www.cliki.net/cl-launch
-(defun leave-lisp (message return)
-  (fresh-line *error-output*)
-  (when message
-    (format *error-output* message)
-    (terpri *error-output*))
-  (finish-output *error-output*)
-  (finish-output *standard-output*)
+(defun exit-lisp (return)
   #+allegro
   (excl:exit return)
   #+clisp
@@ -82,12 +76,23 @@
   (lispworks:quit :status return :confirm nil :return nil :ignore-errors-p t)
   #+(or openmcl mcl)
   (ccl::quit return)
-  #+sbcl
-  (sb-ext:quit :unix-status return)
+  #+sbcl #.(let ((exit (find-symbol "EXIT" :sb-ext))
+                 (quit (find-symbol "QUIT" :sb-ext)))
+             (cond
+               (exit `(,exit :code return :abort t))
+               (quit `(,quit :unix-status return :recklessly-p t))))
   #+(or abcl xcl)
   (ext:quit :status return)
   (error "Don't know how to quit Lisp; wanting to use exit code ~a" return))
 
+(defun leave-lisp (message return)
+  (fresh-line *error-output*)
+  (when message
+    (format *error-output* message)
+    (terpri *error-output*))
+  (finish-output *error-output*)
+  (finish-output *standard-output*)
+  (exit-lisp return))
 
 (defmacro quit-on-error (&body body)
   `(call-quitting-on-error (lambda () ,@body)))
@@ -114,3 +119,52 @@ is bound, write a message and exit on an error.  If
                    (leave-lisp "~&Script failed~%" 1))))))
     (funcall thunk)
     (leave-lisp "~&Script succeeded~%" 0)))
+
+
+;;; These are used by the upgrade tests
+
+(defmacro quietly (&body body)
+  `(call-quietly #'(lambda () ,@body)))
+
+(defun call-quietly (thunk)
+  (handler-bind (#+sbcl (sb-kernel:redefinition-warning #'muffle-warning))
+    (funcall thunk)))
+
+(defun load-asdf-lisp ()
+  (load *asdf-lisp*))
+
+(defun compile-asdf ()
+  (ensure-directories-exist *asdf-fasl*)
+  (compile-file *asdf-lisp* :output-file *asdf-fasl* :verbose t :print t))
+
+(defun load-asdf-fasl ()
+  (load *asdf-fasl*))
+
+(defun compile-load-asdf ()
+  ;; emulate the way asdf upgrades itself: load source, compile, load fasl.
+  (load-asdf-lisp)
+  (compile-asdf)
+  (load-asdf-fasl))
+
+(defun register-directory (dir)
+  (pushnew dir (symbol-value (find-symbol (string :*central-registry*) :asdf))))
+
+(defun asdf-load (x)
+  (let ((xoos (find-symbol (string :oos) :asdf))
+        (xload-op (find-symbol (string :load-op) :asdf)))
+    (funcall xoos xload-op x :verbose t)))
+
+(defun load-asdf-system ()
+  (quietly
+   (register-directory *asdf-directory*)
+   (asdf-load :asdf)))
+
+(defun testing-asdf (thunk)
+  (quit-on-error
+   (quietly
+    (funcall thunk)
+    (register-directory *test-directory*)
+    (asdf-load :test-module-depend))))
+
+(defmacro test-asdf (&body body)
+  `(testing-asdf #'(lambda () ,@body)))
